@@ -33,7 +33,7 @@ class NxPyDocs():
                             # 'show interface transceiver',
                             # 'show inventory',
                             # 'show ip arp vrf all',
-                            # 'show ip interface brief',
+                            'show ip interface brief',
                             # 'show ip ospf',
                             # 'show ip ospf interface',
                             # 'show ip ospf interface vrf all',
@@ -76,11 +76,14 @@ class NxPyDocs():
                 else:
                     click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
             else:
-                if self.filetype != "none":
-                    click.secho("Show command not templated yet")
+                if self.filetype != "json" or "yaml":
+                    command_output = clid( '%s' % self.command )
+                    parsed_json = json.loads(command_output)
+                    self.pick_filetype(parsed_json)                 
                 else:
                     command_output = clid( '%s' % self.command )
                     parsed_json = json.loads(command_output)
+                    click.secho("Show command not templated yet")
                     click.secho(json.dumps(parsed_json,indent=4, sort_keys=True))
 
     def pick_filetype(self, parsed_json):
